@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: eval.h,v 1.186 2014/07/27 16:00:07 plm Exp $
+ * $Id: eval.h,v 1.189 2014/09/08 21:11:51 plm Exp $
  */
 
 #ifndef EVAL_H
@@ -74,11 +74,6 @@ typedef enum {
 #define MAX_INCOMPLETE_MOVES 3875
 #define MAX_MOVES 3060
 
-/* If this is increased, the nSearchCandidates member in struct _evalcontext
- * must also be enlarged. */
-#define MAX_SEARCH_CANDIDATES 127
-
-
 typedef struct movefilter_s {
     int Accept;                 /* always allow this many moves. 0 means don't use this */
     /* level, since at least 1 is needed when used. */
@@ -94,7 +89,7 @@ typedef struct {
     /* FIXME expand this... e.g. different settings for different position
      * classes */
     unsigned int fCubeful:1;    /* cubeful evaluation */
-    unsigned int nPlies:3;
+    unsigned int nPlies:4;
     unsigned int fUsePrune:1;
     unsigned int fDeterministic:1;
     float rNoise;               /* standard deviation */
@@ -113,7 +108,6 @@ typedef struct {
 #define SGF_FORMAT_VER 3
 
 typedef struct {
-
     evalcontext aecCube[2], aecChequer[2];      /* evaluation parameters */
     evalcontext aecCubeLate[2], aecChequerLate[2];      /* ... for later moves */
     evalcontext aecCubeTrunc, aecChequerTrunc;  /* ... at truncation point */
@@ -146,7 +140,6 @@ typedef struct {
     int nSkip;
 } rolloutcontext;
 
-
 typedef struct {
     float rEquity;
     float rJSD;
@@ -158,18 +151,15 @@ typedef enum {
     EVAL_NONE, EVAL_EVAL, EVAL_ROLLOUT
 } evaltype;
 
-
 /* enumeration of variations of backgammon
  * (starting position and/or special rules) */
 
-
 extern bgvariation bgvDefault;
 
 extern int anChequers[NUM_VARIATIONS];
 extern const char *aszVariations[NUM_VARIATIONS];
 extern const char *aszVariationCommands[NUM_VARIATIONS];
 
-
 /*
  * Cubeinfo contains the information necesary for evaluation
  * of a position.
@@ -195,12 +185,10 @@ typedef struct {
     bgvariation bgv;
 } cubeinfo;
 
-
 typedef struct {
     evaltype et;
     evalcontext ec;
     rolloutcontext rc;
-
 } evalsetup;
 
 typedef enum {
@@ -246,7 +234,6 @@ typedef enum {
 
 extern const char *aszDoubleTypes[NUM_DOUBLE_TYPES];
 
-
 /*
  * prefined settings
  */
@@ -267,7 +254,6 @@ extern evalcontext ecBasic;
 extern int aiSettingsMoveFilter[NUM_SETTINGS];
 extern const char *aszSettings[NUM_SETTINGS];
 
-
 #define NUM_MOVEFILTER_SETTINGS 5
 
 extern const char *aszMoveFilterSettings[NUM_MOVEFILTER_SETTINGS];
@@ -338,6 +324,7 @@ typedef enum {
 #define N_CLASSES (CLASS_CONTACT + 1)
 
 #define CLASS_PERFECT CLASS_BEAROFF_TS
+#define CLASS_GOOD CLASS_BEAROFF_OS   /* Good enough to not need SanityCheck */
 
 typedef int (*classevalfunc) (const TanBoard anBoard, float arOutput[], const bgvariation bgv, NNState * nnStates);
 
@@ -434,7 +421,6 @@ extern float
 extern float
  UtilityME(float ar[NUM_OUTPUTS], const cubeinfo * pci);
 
-
 extern int
  SetCubeInfoMoney(cubeinfo * pci, const int nCube, const int fCubeOwner,
                  const int fMove, const int fJacoby, const int fBeavers, const bgvariation bgv);
@@ -555,7 +541,6 @@ extern int
  equal_movefilters(movefilter aamf1[MAX_FILTER_PLIES][MAX_FILTER_PLIES],
                   movefilter aamf2[MAX_FILTER_PLIES][MAX_FILTER_PLIES]);
 
-
 extern doubletype DoubleType(const int fDoubled, const int fMove, const int fTurn);
 
 extern int
@@ -567,7 +552,6 @@ extern void
 extern void
  CalculateRaceInputs(const TanBoard anBoard, float inputs[]);
 
-
 extern int CompareMoves(const move * pm0, const move * pm1);
 extern float EvalEfficiency(const TanBoard anBoard, positionclass pc);
 extern float Cl2CfMoney(float arOutput[NUM_OUTPUTS], cubeinfo * pci, float rCubeX);
